.editable:hover {
    background-color: rgb(240, 240, 255);
}
.editing:hover{background-color: white !important}

.editable.editing > textarea {
    width: 100%;
    height: auto;
    font-family: Monaco, "Liberation Mono", Courier, monospace;
    font-size:12px;
}

.front-edit-ace > .front-edit-container {
    position: relative;
    width: 100%;
    height: 300px;
}
